//
// R package splines2 by Wenjie Wang and Jun Yan
// Copyright (C) 2016-2023
//
// This file is part of the R package splines2.
//
// The R package splines2 is free software: You can redistribute it and/or
// modify it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or any later
// version (at your option). See the GNU General Public License at
// <https://www.gnu.org/licenses/> for details.
//
// The R package splines2 is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//

#ifndef SPLINES2_ARMADILLO_H
#define SPLINES2_ARMADILLO_H

#ifndef ARMA_NO_DEBUG
#define ARMA_NO_DEBUG
#endif

#include "splines2Armadillo/BSpline.h"
#include "splines2Armadillo/MSpline.h"
#include "splines2Armadillo/ISpline.h"
#include "splines2Armadillo/CSpline.h"
#include "splines2Armadillo/BernsteinPoly.h"
#include "splines2Armadillo/NaturalSpline.h"
#include "splines2Armadillo/NaturalSplineK.h"
#include "splines2Armadillo/PeriodicSpline.h"

#endif
